@@ -13,7 +13,7 @@ MooX::Role::JSON_LD - Easily provide JSON-LD mark-up for your objects.
     # define your attributes
     has first_name => ( ... );
     has last_name  => ( ... );
-    has birth date => ( ... );
+    has birth_date => ( ... );
 
     # Add two required methods
     sub json_ld_type { 'Person' };
@@ -144,16 +144,16 @@ package MooX::Role::JSON_LD;
 use 5.6.0;
 
 use Moo::Role;
-use JSON;
 use Carp;
-use Types::Standard qw[InstanceOf Str];
+use JSON::MaybeXS;
+use Types::Standard qw[ArrayRef HashRef InstanceOf Str];
 
-our $VERSION = '0.0.7';
+our $VERSION = '0.0.8';
 
 requires qw[json_ld_type json_ld_fields];
 
 has json_ld_encoder => (
-  isa => InstanceOf['JSON'],
+  isa => InstanceOf[ qw/ Cpanel::JSON::XS JSON JSON::PP JSON::XS /],
   is  => 'ro',
   lazy => 1,
   builder => '_build_json_ld_encoder',
@@ -164,7 +164,7 @@ sub _build_json_ld_encoder {
 }
 
 has context => (
-  isa => Str,
+  isa => Str | HashRef | ArrayRef,
   is  => 'ro',
   builder => '_build_context',
 );
@@ -219,6 +219,9 @@ Dave Cross <dave@perlhacks.com>
 
 perl(1), Moo, Moose, L<https://json-ld.org/>, L<https://schema.org/>
 
+L<MooX::JSON_LD> is included in this distribution and provides an alternative
+interface to the same functionality.
+
 =head1 COPYRIGHT AND LICENSE
 
 Copyright (C) 2018, Magnum Solutions Ltd.  All Rights Reserved.
